# picocolors

    npm install picocolors

A tinier and faster alternative to [nanocolors](https://github.com/ai/nanocolors). Andrey, are you even trying?

```javascript
import { green, italic } from "picocolors";

console.log(green(`How are ${italic(`you`)} doing?`));
```

- Up to [2x faster and 2x smaller](#benchmarks) than alternatives
- 3x faster and 10x smaller than `chalk`
- [TypeScript](https://www.typescriptlang.org/) & [Flowtype](https://flow.org/) support
- [`NO_COLOR`](https://no-color.org/) friendly
- The same API, but faster
- No `String.prototype` modifications
- No dependencies and the smallest `node_modules` footprint
- Tree-shakeable (in case a Node.js package needs it?)

## Prior Art

Credits go to the following projects:

- [Nanocolors](https://github.com/ai/nanocolors) by [@ai](github.chttps://om/ai)
- [Colorette](https://github.com/jorgebucaran/colorette) by [@jorgebucaran](https://github.com/jorgebucaran)
- [Kleur](https://github.com/lukeed/kleur) by [@lukeed](https://github.com/lukeed)
- [Colors.js](https://github.com/Marak/colors.js) by [@Marak](https://github/Marak)
- [Chalk](https://github.com/chalk/chalk) by [@sindresorhus](https://github.com/sindresorhus)

## Benchmarks

`nanocolors` [benchmark](https://github.com/ai/nanocolors/tree/main/test):

```diff
./test/size.js
Data from packagephobia.com
chalk         101 kB
cli-color    1249 kB
ansi-colors    25 kB
kleur          21 kB
colorette      16 kB
nanocolors     16 kB
+picocolors      8 kB
```

```diff
$ ./test/complex-benchmark.js
chalk          2,618,824 ops/sec
cli-color        326,445 ops/sec
ansi-colors    1,057,188 ops/sec
kleur          2,543,659 ops/sec
kleur/colors   2,841,679 ops/sec
colorette      3,219,038 ops/sec
nanocolors     3,672,600 ops/sec
+picocolors     6,079,950 ops/sec
```

`colorette` [benchmark](https://github.com/jorgebucaran/colorette/tree/main/bench):

```diff
$ npm start
+picocolors × 1,203,773 ops/sec
chalk × 474,359 ops/sec
kleur × 482,915 ops/sec
colors × 233,138 ops/sec
colorette × 657,896 ops/sec
nanocolors × 660,817 ops/sec
ansi-colors × 290,986 ops/sec
```

## Replacing nanocolors

Just replace imports

```diff
-import { green, italic } from 'nanocolors';
+import { green, italic } from 'picocolors';
```
